@@ -2,7 +2,8 @@
 # dgit
 # Debian::Dgit: functions common to dgit and its helpers and servers
 #
-# Copyright (C) 2015-2019  Ian Jackson
+# Copyright (C)2015-2020,2022-2023 Ian Jackson
+# Copyright (C)2020                Sean Whitton
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -549,8 +550,10 @@ sub hashfile ($) {
     return $h->hexdigest();
 }
 
-sub git_rev_parse ($) {
-    return cmdoutput qw(git rev-parse), "$_[0]~0";
+sub git_rev_parse ($;$) {
+    my ($ref, $cmdprefix) = @_;
+    $cmdprefix //= [ ];
+    return cmdoutput @$cmdprefix, qw(git rev-parse), "$ref~0";
 }
 
 sub changedir_git_toplevel () {
@@ -861,9 +864,12 @@ sub parsecontrol {
 }
 
 sub parsechangelog {
+    # parsechangelog [ \@cmdprefix ], @dpkg_changelog_args
     my $c = Dpkg::Control::Hash->new(name => 'parsed changelog');
     my $p = new IO::Handle;
-    my @cmd = (qw(dpkg-parsechangelog), @_);
+    my $prefix = [ ];
+    $prefix = shift @_ if ref $_[0];
+    my @cmd = (@$prefix, qw(dpkg-parsechangelog), @_);
     open $p, '-|', @cmd or confess "$!";
     $c->parse($p);
     $?=0; $!=0; close $p or failedcmd @cmd;
